==> fred-hermes-0.5.1.tar.gz: fred-hermes-0.5.1/hermes/sms.py <==
"""High level API for SMS."""
from typing import Any, Dict
from uuid import UUID

from typist import SecretaryClient

from .message import Message, MessageEnvelope


class Sms(Message):
    """Provide a structure for SMS message."""

    rendered_fields = ('body',)

    def __init__(
        self,
        recipient: str,
        body_template: str,
        *,
        body_template_uuid: UUID = None,
        context: Dict[str, Any] = None,
        type: str = None,
        secretary_client: SecretaryClient = None
    ):
        """Create SMS message."""
        super().__init__(type=type, secretary_client=secretary_client)
        self.recipient = recipient
        self.body_template = body_template
        self.body_template_uuid = body_template_uuid
        self.context = context or {}

    @property
    def body(self) -> str:
        """Render body using django-secretary."""
        return self._secretary_render(
            'body',
            template=self.body_template_uuid or self.body_template,
            render_method_name='render',
        )

    def to_dict(self) -> Dict[str, Any]:
        """Return dictionary with e-mail info.

        This method is useful for SMS serialization.
        """
        info = super().to_dict()
        info.update({
            'recipient': self.recipient,
            'body_template': self.body_template,
            'body_template_uuid': self.body_template_uuid,
            'context': self.context,
        })
        return info


class SmsEnvelope(MessageEnvelope[Sms]):
    """Provide a structure for SMS envelope."""

    message_cls = Sms

==> fred-hermes-1.0.0.tar.gz: fred-hermes-1.0.0/hermes/sms.py <==
"""High level API for SMS."""
from typing import Any, Dict
from uuid import UUID

from typist import SecretaryClient

from .message import Message, MessageEnvelope


class Sms(Message):
    """Provide a structure for SMS message."""

    rendered_fields = ('body',)

    def __init__(
        self,
        recipient: str,
        body_template: str,
        *,
        body_template_uuid: UUID = None,
        context: Dict[str, Any] = None,
        type: str = None,
        secretary_client: SecretaryClient = None
    ):
        """Create SMS message."""
        super().__init__(type=type, secretary_client=secretary_client)
        self.recipient = recipient
        self.body_template = body_template
        self.body_template_uuid = body_template_uuid
        self.context = context or {}

    @property
    def body(self) -> str:
        """Render body using django-secretary."""
        return self._secretary_render(
            'body',
            template=self.body_template_uuid or self.body_template,
            render_method_name='render',
        )

    def to_dict(self) -> Dict[str, Any]:
        """Return dictionary with SMS info.

        This method is useful for SMS serialization.
        """
        info = super().to_dict()
        info.update({
            'recipient': self.recipient,
            'body_template': self.body_template,
            'body_template_uuid': self.body_template_uuid,
            'context': self.context,
        })
        return info


class SmsEnvelope(MessageEnvelope[Sms]):
    """Provide a structure for SMS envelope."""

    message_cls = Sms
